#!/bin/bash

# Number of hours since enrollment device must be UNDER to go through Onboarding
# Examples: 1 day = 24 | 1 week = 168 | 1 month = 730
cutOffTime=168

# Checks if Onboarding already ran
checkFilePath="/var/log/Baseline-Report.txt"
if ls "$checkFilePath" &> /dev/null; then
	echo "File $checkFilePath exists"
	exit 1
else
	echo "File $checkFilePath does not exist"
fi

# If Onboarding has not ran, how long has the device already existed in Addigy.
# Get the current epoch time
current_epoch=$(date +%s)

# Gets created date of .adg_agent_config and converts it to epoch
file_epoch=$(stat -f "%B" /Library/Addigy/config/.adg_agent_config)

# Convert Cutoff Time to epoch time
eCutOffTime=$((cutOffTime * 3600))

# Calculate the difference between current time and the other timestamp
difference=$((current_epoch - file_epoch))

# Print time since last enrollment based on length.
# If less than 72 hours print hours
# If more then print in days
hours=$((difference / 3600))
if ((hours>=72)); then
    days=$((difference / 86400))
    echo "Days since enrollment: $days"
else
    echo "Hours since enrollment $hours"
fi

# Check if the difference is less than 24 hours (86,400 seconds)
if [ "$difference" -lt "$eCutOffTime" ]; then
    echo "The difference between the current time and the other timestamp is less than $cutOffTime."
    echo "Recent Enrollment"
    exit 0
else
    echo "The difference between the current time and the other timestamp is more than $cutOffTime."
    echo "Old enrollment"
    exit 1
fi